@@ -120,7 +120,8 @@ def GOBC_PA(func,rang,target,N,ite,pop_size):
             x_yer=x_yer[:,0]
             if np.sum(x_yer) > 2:
                 A = np.concatenate((popu[x_yer,:]**2 , popu[x_yer,:] , np.ones((np.sum(x_yer), 1))), axis=1)
-                param = np.dot(np.dot(np.linalg.pinv(np.dot(A.T,A)),A.T),evali[x_yer])
+                # param = np.dot(np.dot(np.linalg.pinv(np.dot(A.T,A)),A.T),evali[x_yer])
+                param = np.linalg.lstsq(A, evali[x_yer], rcond=None)[0]
                 tepe = (-param[param_n:-1] / (2 * param[0:param_n]))
 
                 ind = param[param_n:-1] == 0
